@@ -1,6 +1,6 @@
 package Package::Pkg;
 BEGIN {
-  $Package::Pkg::VERSION = '0.0012';
+  $Package::Pkg::VERSION = '0.0013';
 }
 # ABSTRACT: Handy package munging utilities
 
@@ -17,7 +17,7 @@ __PACKAGE__->export( pkg => \&pkg );
 
 sub package {
     my $self = shift;
-    my $package = join '::', @_;
+    my $package = join '::', map { ref $_ ? ref $_ : $_ } @_;
     $package =~ s/:{2,}/::/g;
     return '' if $package eq '::';
     if ( $package =~ m/^::/ ) {
@@ -166,7 +166,7 @@ Package::Pkg - Handy package munging utilities
 
 =head1 VERSION
 
-version 0.0012
+version 0.0013
 
 =head1 SYNOPSIS
 
@@ -174,6 +174,11 @@ First, import a new keyword: C<pkg>
 
     use Package::Pkg;
 
+Package name formation:
+
+    pkg->package( 'Xy', 'A' ) # Xy::A
+    pkg->package( $object, qw/ Cfg / ); # (ref $object)::Cfg
+
 Subroutine installation:
 
     pkg->install( sub { ... } => 'MyPackage::myfunction' );
@@ -189,7 +194,8 @@ Subroutine exporting:
 
     sub this { ... }
 
-    # Setup an exporter for MyPackage, exporting 'this' and 'that'
+    # Setup an exporter (literally sub import { ... }) for
+    # MyPackage, exporting 'this' and 'that'
     pkg->export( that => sub { ... }, 'this' );
 
     package main;
@@ -218,14 +224,20 @@ Superfluous/redundant C<::> are automatically cleaned up and stripped from the r
 
 If the first part leads with a C<::>, the the calling package will be prepended to $package
 
-    pkg->package( 'Xyzzy', 'Apple::', '::Banana' ) # 'Xyzzy::Apple::Banana' 
-
-    pkg->package( 'Xyzzy', 'Apple::' ) # 'Xyzzy::Apple::
+    pkg->package( 'Xy', 'A::', '::B' )      # Xy::A::B
+    pkg->package( 'Xy', 'A::' )             # Xy::A::
     
-    package Cherry;
-    pkg->package( '::', 'Apple::', '::Banana' ) # 'Cherry::Apple::Banana'
+    {
+        package Zy;
 
-    pkg->package( '::Xyzzy::A::B' ) # 'Cherry::Xyzzy::A::B'
+        pkg->package( '::', 'A::', '::B' )  # Zy::A::B
+        pkg->package( '::Xy::A::B' )        # Zy::Xy::A::B
+    }
+
+In addition, if any part is blessed, C<package> will resolve that part to the package that the part makes reference to:
+
+    my $object = bless {}, 'Xyzzy';
+    pkg->package( $object, qw/ Cfg / );     # Xyzzy::Cfg
 
 =head2 export( ... )
 
